#
# spec file for package msmtp
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           msmtp
Version:        1.8.28
Release:        1.1
BuildRequires:  gnutls-devel >= 3.4
BuildRequires:  libidn2-devel
BuildRequires:  pkg-config
BuildRequires:  xz
%if 0%{?suse_version} || 0%{?centos_version} == 700
# keyring integration for recent openSUSE and CentOS
BuildRequires:  libsecret-devel
%endif
%if 0%{?suse_version}
BuildRequires:  libgsasl-devel >= 2.1.0
%endif
# for the directory
%if 0%{?centos_version}
BuildRequires:  vim-common
%else
BuildRequires:  vim-base
%endif #centos_version
%if 0%{?suse_version}
Requires(post): %install_info_prereq
Requires(preun): %install_info_prereq
%endif
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version}
Requires(post): /sbin/install-info
Requires(preun): /sbin/install-info
%endif
Summary:        Lightweight SMTP Client
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Email/Utilities
URL:            https://marlam.de/msmtp/
Source:         https://marlam.de/msmtp/releases/msmtp-%{version}.tar.xz
Source1:        https://marlam.de/msmtp/releases/msmtp-%{version}.tar.xz.sig
Source2:        %{name}.keyring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
msmtp is an SMTP client that can be used as a plug-in for Mutt and
other mail user agents.  It forwards mail to an SMTP server that does
the delivery.  msmtp supports multiple accounts.

%lang_package

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
Requires:       %{name} = %{version}
BuildArch:      noarch

%description doc
msmtp is an SMTP client that can be used as a plug-in for Mutt and
other mail user agents.  It forwards mail to an SMTP server that does
the delivery.  msmtp supports multiple accounts.

This subpackage contains the documentation for %{name}, including
examples and sample configuration files.

%package mta
Summary:        MTA based on %{name}
Group:          Productivity/Networking/Email/Servers
Requires:       %{name} = %{version}
Conflicts:      exim
Conflicts:      postfix
Conflicts:      postfix-bdb
Conflicts:      sendmail
Conflicts:      sendmail-tls
Provides:       smtp_daemon

%description mta
msmtp is an SMTP client that can be used as a plug-in for Mutt and
other mail user agents.  It forwards mail to an SMTP server that does
the delivery.  msmtp supports multiple accounts.

This subpackage provides a mail transfer agent that can be used as
a minimalistic replacement of sendmail and a minimal SMTP server.

%prep
%setup -q
# fix bash and sh scripts shebang while preserving mtime
for i in scripts/msmtpqueue/*.sh \
         scripts/msmtpq/msmtpq \
         scripts/msmtpq/msmtp-queue \
         scripts/set_sendmail/*.sh \
         scripts/find_alias/*.sh; do
    sed '1 s|#!/usr/bin/env \(.*\)|#!/bin/\1|' $i > $i.new
    touch -r $i $i.new
    mv $i.new $i
done

%build
%configure --docdir="%{_docdir}/%{name}" --with-tls=gnutls --with-libgsasl
%make_build

%install
%make_install V=1
%find_lang %{name}
for i in README ChangeLog ; do
    cp scripts/msmtpqueue/$i ${i}.msmtpqueue
done
cp scripts/msmtpq/README.msmtpq    README.msmtpq
cp scripts/vim/README              README.vim

install -m 0755 \
        scripts/msmtpqueue/*.sh \
        scripts/msmtpq/msmtpq \
        scripts/msmtpq/msmtp-queue \
        scripts/set_sendmail/*.sh \
        scripts/find_alias/*.sh \
    %{buildroot}%{_bindir}

# find where to install vim syntax
# start with the "site" directory, then "current" and finally any "vim??"
for vimsyntax in %{_datadir}/vim/{site,current,vim[0-9][0-9]}/syntax; do
    if [ -d $vimsyntax ]; then
        break
    fi
done
install -D -m 0644 scripts/vim/syntax/msmtp.vim %{buildroot}$vimsyntax/msmtp.vim

# main package doc files
for f in \
COPYING\
; do
    install -D -m0644 "$f" "%{buildroot}%{_docdir}/%{name}/$f"
done

# doc files
echo -n >docfiles.lst
for f in \
AUTHORS ChangeLog* NEWS README README.msmtpqueue README.msmtpq THANKS \
doc/*.example \
scripts/set_sendmail/set_sendmail.conf \
; do
    ff="${f##*/}"
    install -D -m0644 "$f" "%{buildroot}%{_docdir}/%{name}/$ff"
    echo "%doc %{_docdir}/%{name}/$ff" >>docfiles.lst
done

# mta files
install -d %{buildroot}%{_sbindir}
ln -s %{_bindir}/msmtp %{buildroot}%{_sbindir}/sendmail
ln -s %{_mandir}/man1/msmtp.1%{ext_man} %{buildroot}%{_mandir}/man1/sendmail.1%{ext_man}

# not properly ignored on Fedora 10:
rm -f "%{buildroot}%{_infodir}/dir"

%if 0%{?suse_version}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/msmtp.info%{ext_info}

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/msmtp.info%{ext_info}
%endif
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version}

%post
[ "$1" = "1" ] && /sbin/install-info "%{_infodir}/%{name}.info%{ext_info}" || :

%preun
[ "$1" = "0" ] && /sbin/install-info --delete "%{_infodir}/%{name}.info%{ext_info}" || :
%endif # fedora

%files
%doc %dir %{_docdir}/%{name}
%license %{_docdir}/%{name}/COPYING
%{_bindir}/msmtp
%{_bindir}/msmtpq
%{_bindir}/msmtp-queue
%{_bindir}/msmtp-enqueue.sh
%{_bindir}/msmtp-runqueue.sh
%{_bindir}/msmtp-listqueue.sh
%{_bindir}/set_sendmail.sh
%{_bindir}/find_alias_for_msmtp.sh
%{_mandir}/man1/msmtp.1%{?ext_man}
%{_infodir}/msmtp.info%{?ext_info}
%{_datadir}/vim/*/syntax/msmtp.vim

%files lang -f %{name}.lang

%files doc -f docfiles.lst
%doc %dir %{_docdir}/%{name}

%files mta
%{_bindir}/msmtpd
%{_sbindir}/sendmail
%{_mandir}/man1/msmtpd.1%{?ext_man}
%{_mandir}/man1/sendmail.1%{?ext_man}

%changelog
* Tue Jan 14 2025 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.28:
  * Detect SMTPUTF8 server capability and use it if available.
  * Add IDN support to --configure (build with libidn2 to enable
    this).
  * Add special value 'none' to logfile_time_format to suppress
    time output.
* Fri Nov 15 2024 Benoît Monin <benoit.monin@gmx.fr>
- stop requiring vim at runtime just for the syntax file
* Sun Oct  6 2024 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.27:
  * The option -F was fixed: it now overrides the configuration
    file setting again (this bug was introduced in 1.8.24), and
    non-ASCII characters are now properly encoded in the From
    header.
  * The msmtpq script was improved by Github user Konfekt.
  * The vim script for configuration file editing was improved by
    Github user Konfekt.
  * A testing infrastructure was added (make check).
  * Translations were updated and a new Spanish translation was
    added
- update vim syntax path
* Thu Jun 13 2024 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.26:
  * Add support for SCRAM-SHA-256-PLUS and SCRAM-SHA-1-PLUS
    authentication, and prefer SCRAM methods over the PLAIN method
    because of their superior properties.
  * With --read-envelope-from, a Resent-From header is now used if
    it is present and appears before any From header
- require libgsasl >= 2.1.0: needed for supporting SCRAM
* Sun Oct 29 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.25:
  * Generation of Message-ID headers was improved to avoid problems
    with rspamd assigning SPAM points
  * Documentation of ignored options was fixed
  * The combination of envelope from addresses with wildcards and
    automatic account selection was fixed
  * Translations were updated, including a new Romanian translation
* Fri Jun 30 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.24:
  * Added a new configuration command 'from_full_name' to set a
    full name for the From header (like -F on the command line)
  * Fixed the allow_from_override command
* Mon Jan 30 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.23:
  * This release fixes XOAUTH2 authentication with some servers,
    updates the msmtpq scripts, and updates the translations
    (including a new Swedish translation).
* Sun Aug  7 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.22:
  * This is a hotfix release that fixes building with libgsasl,
    which was accidentally broken in version 1.8.21.
  * It also updates the msmtpq script.
- additional changes from version 1.8.21:
  * A new configuration command eval replaces the current
    configuration file line with the output of a command (similar
    to passwordeval, but more general).
  * A Message-ID header is now generated if none is present in the
    mail. This can be changed with the new command set_msgid_header.
  * The optional msmtpd service now adds a Received header.
  * Furthermore, a few minor problems were corrected and the
    documentation and translations were updated.
- mark the doc sub-package as noarch
* Wed Mar 23 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.20:
  * Added a new configuration command 'allow_from_override'. When
  off, the --from option does not override the envelope-from
  address anymore.
* Thu Nov  4 2021 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.19:
  * Fixed a security problem in msmtpd: mail addresses starting
    with '-' could be interpreted as options of the pipe command.
* Sat Oct 23 2021 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.18:
  * this release fixes a few minor problems related to translations
    and the documentation.
- additional changes from version 1.8.17:
  * msmtpd now supports logging to syslog or to a file with the
    option --log, and authentication (for special use cases) with
    the option --auth.
- build msmtpd and package it in msmtp-mta
* Tue Sep 14 2021 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.16:
  * The 'from' command now accepts patterns (as in shell file name
    matching) so that many envelope from addresses given with
  - -from can match the same account
  * Added support for %%H, %%C, %%M in the domain command
  * msmtpd now supports sysexits.h error codes from the pipe
    command
- cleanup obsolete suse_version check
* Tue Mar 30 2021 Benoît Monin <benoit.monin@gmx.fr>
- add package conflict with postfix-bdb for msmtp-mta
* Fri Mar 12 2021 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.15:
  * Added support for SCRAM-SHA-256 authentication via GNU SASL
* Thu Dec 24 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.14:
  * Added support for libtls as an alternative to GnuTLS
* Fri Nov 13 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.13:
  * Added support for XOAUTH2, the predecessor of OAUTHBEARER.
  * The passwordeval command can now handle very long input, which
    can be necessary for OAUTHBEARER and XOAUTH2.
  * GnuTLS >= 3.4 is required
- set the required minimum version for gnutls
* Fri Aug 21 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.12:
  * msmtpd now supports session reuse and improves standards
    compliance
  * Automatic account matching now supports subaddresses. For
    example, user+detail@example.com will match account
    user@example.com.
- put the translations into a separate sub-package
* Thu Jun  4 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.11:
  * Add a new undisclosed_recipients command and
  - -undisclosed-recipients option to replace To, Cc, Bcc with a
    single "To: undisclosed-recipients:;" header.
  * Improved handling of temporary files on Windows systems.
  * Re-enabled support for systems lacking vasprintf(),
    such as IBM i PASE.
- spec cleaning:
  * drop reference to suse_version 10
  * use make_build and make_install macros
  * remove defattr from %%files sections
  * use %%license for the license file instead of doc
  * fix the man and info pages extension
* Thu May 14 2020 Marcus Rueckert <mrueckert@suse.de>
- gnu sasl support needs to be enabled with a configure option
  (boo#1170516)
* Thu Apr 23 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.10:
  * This release fixes the msmtpq script that was accidentally
    broken in 1.8.8.
  * Furthermore, internationalization files are updated and a new
    serbian translation is included. Thanks to the translators at
    translationproject.org!
  * Note that version 1.8.9 only partially fixed the msmtpq problem
    and was quickly replaced by 1.8.10.
* Sun Apr 12 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.8:
  * Added a new socket command and --socket option to connect via
    local sockets.
  * Added a new tls_host_override command and --tls-host-override
    option to override the host name used for TLS verification.
  * Added a new set_from_header command and --set-from-header
    option with three settings:
    + on: always set a From header, possibly replacing an existing
    one
    + off: never set a From header
    + auto: add a From header if there is none (this is the
    default).
    This replaces the add_missing_from_header option (which remains
    supported).
  * Added a new set_date_header command and --set-date-header
    option with two settings:
    + off: never set a Date header
    + auto: add a Date header if there is none (this is the
    default).
    This replaces the add_missing_date_header option (which remains
    supported).
  * Fixed the handling of empty From headers with
  - -read-recipients/-t.
  * Fixed the source_ip command for proxies.
- update expired msmtp.keyring
* Tue Dec 24 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.7:
  * Add support for %%U,%%H,%%C,%%M in 'from'
    This makes the auto_from and maildomain commands obsolete
  * Do not call gnutls_free() needlessly
* Fri Sep 27 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.6:
  * Aliases are now expanded recursively
  * Minor bug fixes
* Fri Jul 12 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.5:
  * Fixed OAUTHBEARER.
  * Support for TLS client certificates via PKCS11 devices, e.g.
    smart cards.
  * Various small bug fixes and improvements.
- fix sh scripts shebang, in addition to bash scripts
* Wed Apr 24 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.4
  * Added support for the OAUTHBEARER authentication method.
  * Several minor bug fixes.
* Thu Feb 14 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.3 (boo#1125420)
  * CVE-2019-8337
    This version fixes a security problem that affects version
    1.8.2 (older versions are not affected): when the new default
    value system for tls_trust_file is used, the result of
    certificate verification was not properly checked.
* Wed Feb 13 2019 Tomas Cech <sleep_walker@opensuse.org>
- use GnuTLS instead of OpenSSL
  https://marlam.de/msmtp/news/openssl-discouraged/
* Wed Jan 16 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.8.2:
  * To simplify TLS setup, the tls_trust_file command has a new
    default value 'system' that selects the system default trust.
  * To simplify setup, a new option '--configure <mailaddress>' was
    added that automatically generates a configuration file for a
    given mail address.
- additional changes from version 1.8.1:
  * Fixed our TLS code to support TLS 1.3 with GnuTLS.
- additional changes from version 1.8.0:
  * A minimal SMTP server called msmtpd was added that listens on
    the local host and pipes mails to msmtp (or another program).
    It is intended to be used with system services that cannot be
    configured to call msmtp directly. You can disable it with the
    configure option --without-msmtpd.
  * Using OpenSSL is discouraged and may not be supported in the
    future. Please use GnuTLS instead. The reasons are explained
    here: https://marlam.de/msmtp/news/openssl-discouraged/
  * As using GNU SASL is most likely unnecessary, it is disabled by
    default now. Since everything uses TLS nowadays and thus can
    use PLAIN authentication, you really only need it for GSSAPI.
  * If your system requires a library for IDN support, libidn2 is
    now used instead of the older libidn.
  * The CRAM-MD5 authentication method is marked as obsolete /
    insecure and will not be chosen automatically anymore.
  * The passwordeval command does not require the password to be
    terminated by a new line character anymore.
  * The new logfile_time_format command allows to customize log
    file time stamps.
  * Builtin default port numbers are now used instead of consulting
    /etc/services.
  * Support for DJGPP and for systems lacking vasprintf(),
    mkstemp(), or tmpfile() is removed.
- additional changes from version 1.6.8:
  * Add --source-ip option and source_ip command to bind the
    outgoing connection to a specific source IP address.
  * Enable SNI for TLS
- additional changes from version 1.6.7:
  * Add support for ~/.config/msmtp/config as configuration file
  * Add network timeout handling on Windows
  * Fix command line handling of SHA256 TLS fingerprints
  * Fix SIGPIPE handling (affects at least Mac OS X)
  * Add french translation, and update german translation
- update Url and Source to marlam.de, see:
  https://marlam.de/msmtp/news/project-moved/
- update the keyring, the previous one has been revoked
- switch to libidn2 to match msmtp requirement
- configure with openssl as tls library
* Sat Mar 10 2018 benoit.monin@gmx.fr
- fix bash scripts shebang
* Sun Mar 26 2017 dev+novell@devmotion.de
- Keyring integration only for recent openSUSE and CentOS
* Sun Mar 26 2017 dev+novell@devmotion.de
- Replace pkgconfig dependencies
* Sun Mar 26 2017 dev+novell@devmotion.de
- Add keyring integration
* Mon Nov 14 2016 benoit.monin@gmx.fr
- update to version 1.6.6:
  * This version fixes a memory leak and a double-free in
    msmtp_read_headers(). The double-free was triggered by read
    errors.
- remove reference to msmtp-fix-newopenssl.patch:
  this patch was removed 5 years ago.
* Tue May 31 2016 benoit.monin@gmx.fr
- update to version 1.6.5:
  * Support SHA256 fingerprints for tls_fingerprint,
    and mark both SHA1 and MD5 as deprecated.
* Tue Feb  2 2016 benoit.monin@gmx.fr
- update to version 1.6.4:
  * The system default policy is used with GnuTLS instead of
    a hardcoded one.
* Sun Nov 29 2015 benoit.monin@gmx.fr
- update to version 1.6.3:
  * A bug in SOCKS support was fixed.
  * Handling non-fatal errors in TLS handshakes was fixed.
- fix info installation for suse package:
  * properly requires %%install_info_prereq
  * call %%install_info_delete in preun, not postun
* Fri Apr 24 2015 benoit.monin@gmx.fr
- update to version 1.6.2:
  * A bug was fixed that prevented consecutive Bcc headers from
    being removed properly.
- add tarball signature and keyring
* Mon Jan  5 2015 benoit.monin@gmx.fr
- update to version 1.6.1:
  * The new configure option --with-tls replaces --with-ssl.
  * A new configure option --disable-gai-idn was added.
- additional changes from 1.6.0:
  * Support for SOCKS proxies was added. This allows msmtp to be
    used with Tor.
  * GNOME Keyring support now uses libsecret instead of
    libgnome-keyring. It is now documented how to use secret-tool
    to manage passwords for msmtp; the obsolete msmtp-gnome-tool
    script is removed.
  * Configuration file security is now only checked if the file
    actually contains secrets such as passwords.
  * The GSSAPI authentication method is not chosen automatically
    anymore, you have to request it manually if you really want to
    use it.
  * From: and Date: headers are now added to mails if necessary, for
    compatibility with sendmail, postfix, exim, and other MTAs. This
    can be disabled with the add_missing_from_header and
    add_missing_date_header commands.
  * Libidn is not required for IDN support anymore on systems where
    getaddrinfo() supports the AI_IDN flag and the GnuTLS version
    is >= 3.4.0.
  * The new remove_bcc_headers command replaces the old keepbcc
    command (but the old command is still supported for
    compatibility).
  * SSLv3 is disabled, and the obsolete tls_force_sslv3 command and
  - -tls-force-sslv3 option have no effect anymore.
- add xz as BuildRequires: source archive format is now tar.xz
- switch gnome keyring support to libsecret
- remove msmtp-gnome-tool.py: deleted upstream
- remove README.msmtp-gnome-tool: deleted upstream
- remove Mutt+msmtp.txt: deleted upstream
* Tue Jul 29 2014 benoit.monin@gmx.fr
- update to version 1.4.32:
  * A recipient list on the command line is now parsed as if it
    appeared in a mail header.
* Mon Jan 13 2014 benoit.monin@gmx.fr
- rework the path lookup for the vim syntax file: fix fedora and
  redhat build
* Sun Dec 29 2013 benoit.monin@gmx.fr
- update to version 1.4.31:
  * Updated the msmtpq script.
  * Fixed building of the documentation with texinfo >= 5.0.
- additional changes from version 1.4.30:
  * Fix a bug in msmtp_read_addresses() that was introduced in
    version 1.4.29 by fixing a problem in the wrong way.
- additional changes from version 1.4.29:
  * Fix bugs in msmtp_read_addresses(), including a crash.
  * Removed autotools files that are automatically copied by
    'autoreconf -i' from repository.
  * Properly require an argument to --passwordeval. Fixes a crash
    when none is given.
  * Replace old service name "ssmtp" with current one: "smtps".
* Wed Nov 20 2013 tbehrens@suse.com
- use valid spelling for keyring enabling macro
* Fri Apr 19 2013 mrueckert@suse.de
- we dont use the unversion path anymore for installing the
  extension: use requires_eq for requiring vim.
* Wed Apr 17 2013 idonmez@suse.com
- /usr/share/vim/current is a symlink, resolve it before putting
  any file under there.
* Sat Oct 20 2012 benoit.monin@gmx.fr
- create a -mta subpackage, providing smtp_daemon.
- build msmtp with -fPIE/pie.
* Tue Jun  5 2012 puzel@suse.com
- update to version 1.4.28:
  - Update autotools files.
  - Improve error message on connection failures in some IPv6/IPv4
    situations.
  - Improve documentation of EHLO issues.
  - Bug fix: expand tilde for the aliases command.
* Tue Jan 10 2012 mrueckert@suse.de
- update to version 1.4.27:
  - No significant changes.
- additional changes from vrsion 1.4.26:
  - A new version of the msmtpq script fixes serious bugs. To
    update to the new version of the script, you need to remove the
    old msmtpQ symlink, change msmtpQ to msmtpq in your MUA config,
    and use msmtp-queue for queue management.
- additional changes from version 1.4.25:
  - DIGEST-MD5 authentication is not considered secure any longer.
    See RFC 6331.
  - Support for alias expansion was added. See the aliases command
    and --aliases option.
- add support for building with gnome-keyring (disabled by default)
  call build with --with-gnome-keyring to enable it
- make sure compiler cmdlines are listed (make V=1)
- handle rename from upstream:
  msmtpQ is gone. the new script is called msmtp-queue
- installed msmtp-gnome-tool.py and related readme
* Mon Sep 19 2011 wr@rosenauer.org
- update to version 1.4.24
  - fixes SCRAM-SHA-1 authentication via GNU SASL
  - cleanup that updates the build system and removes old cruft
    and unnecessary complexity, without changing the functionality
    of the program
- spec cleanup
* Mon Jan 10 2011 gber@opensuse.org
- update to version 1.4.22
  - avoid different account selection behaviour in --pretend mode,
    and print more informational messages about account selection
    in --pretend and --debug mode
  - add a new passwordeval command and --passwordeval option, to
    set the password from the output of a command
  - a few documentation improvements
  - report platform in --version output
  - fix building with newer OpenSSL versions
  - updated find_alias_for_msmtp.sh script
  - fixed building without TLS/SSL support
- removed obsolete msmtp-fix-newopenssl.patch
* Mon Apr 19 2010 meissner@suse.de
- fix build with new openSSL
* Sun Mar 21 2010 pascal.bleser@opensuse.org
- update to version 1.4.20
  - adds support for the authentication mechanism SCRAM-SHA-1 via
    GNU SASL (only on openSUSE >= 11.2)
  - the new command tls_fingerprint allows one to trust one
    particular TLS certificate, in case tls_trust_file cannot be
    used for some reason
  - the new script msmtp-gnome-tool.py manages Gnome Keyring
    passwords for msmtp (currently disabled in this build)
- moved documentation files to a -doc subpackage
* Fri Nov 20 2009 mrueckert@suse.de
- update to version 1.4.19
  - When using OpenSSL, msmtp now correctly handles NUL characters
    in the Common Name and Subject Alternative Name fields of
    certificates. This fixes a security problem. Note that msmtp is
    not affected by this problem if GnuTLS is used. (bnc#557181)
  - Disable security checks on the user configuration file when run
    as root.  Fixes Debian bug #534829.
- additional changes from version 1.4.18:
  - mostly code worker
- additional changes from version 1.4.17:
  - Msmtp now also reads SYSCONFDIR/netrc if the password was not
    found in ~/.netrc.
  - Support for the GNOME keyring was added by Satoru SATOH.
- additional changes from version 1.4.16:
  - mostly code rework
- additional changes from version 1.4.15:
  - The configuration command tls_crl_file was added. This allows
    to use certificate revocation lists (CRLs) during certificate
    verification.
  - The configuration command tls_min_dh_prime_bits was added. This
    may be needed to use TLS/SSL with servers that use a small
    Diffie-Hellman (DH) prime size.
  - The configuration command tls_priorities was added. This allows
    to fine tune TLS/SSL session parameters.
* Sat Sep  6 2008 mrueckert@suse.de
- update to version 1.4.16
  - Changed all scripts to '#!/usr/bin/env bash' instead of
    '#!/bin/sh' or '#!/bin/bash', because they use bash features
    that are not available in POSIX /bin/sh and because bash might
    not live in /bin, e.g. on BSD systems. This is a quick fix for
    Debian bug #489635.
  - Accept both 250 and 251 in return of the RCPT TO command, as
    required by RFC 2821 sections 4.3.2 and 3.4. Reported and fixed
    by Matthias Bernhardt.  Thanks!
  - Fix scripts/msmtpqueue/msmtp-runqueue.sh. An error made while
    applying a patch accidently broke it. Reported by Thomas Weber.
    Thanks!
    (this obsoletes msmtp-runqueue.sh.patch)
- additional changes from version 1.4.15
  - Added the new tls_crl_file configuration command and the
    corresponding --tls-crl-file option.
  - Added the new tls_min_dh_prime_bits configuration command and
    the corresponding --tls-min-dh-prime-bits option. This closes
    Debian bug #440344.
  - Added the new tls_priorities configuration command and the
    corresponding --tls-priorities option.
  - Gnulib upate to 2008-06-02. Use getpass-gnu instead of getpass
    module.
  - Add msmtpq scripts by Chris Gianniotis to the scripts
    directory. Suggest them as a replacement in the README of the
    msmtpqueue scripts.
  - Do not let getpass() read from stdin, because we read the mail
    from there.  Reported by Karol Lewandowski. Thanks!
  - Updated the set_sendmail script by Gautam Iyer. Thanks!
  - Return EX_TEMPFAIL instead of EX_DATAERR in case of  4xx
    replies to the MAIL FROM, RCPT TO and DATA commands. Reported
    by Kent Vinther Friis. Thanks!
- install msmtpq
* Wed May  7 2008 cthiel@suse.de
- fix msmtp-runqueue.sh
* Tue Mar 18 2008 mrueckert@suse.de
- update to version 1.4.14
  - The -t option now properly supports Resent-* headers.
  - The --read-envelope-from option was added. It allows to read
    the envelope from address from the From header.
  - The environment variables SMTPSERVER and EMAIL can be used to
    configure msmtp for simple use cases.
  - Support for the Mac OS X keychain was added by Jay Soffian.
* Sat Aug  4 2007 mrueckert@suse.de
- update to version 1.4.13
  - Added the set_sendmail.sh script by Gautam Iyer to the new
    scripts subdirectory.
  - Added the msmtpqueue scripts to the new scripts subdirectory.
  - Make the search of an account by the envelope from address case
    insensitive.  Problem reported and fixed by Brandon Philips.
  - Update the license of the source code to GPLv3 or later, and
    change the license of the documentation to the GFDLv1.2 or
    later.
  - Gnulib update to 2007-07-15.
- no longer use the external msmtpqueue package.
* Sun Jun 17 2007 bwalle@suse.de
- update to version 1.4.12:
  o Handle MAILER-DAEMON correctly
  o documentation updates
  o Require tls_trust_file or tls_certcheck=off for TLS sessions
  o Do not use NTLM authentication automatically
  o Gnulib update
  o bug fixes
- update to msmtpqueue 0.5:
  o Added the msmtp-listqueue.sh script
* Tue Apr 10 2007 mrueckert@suse.de
- update to 1.4.11:
  - Require either tls_trust_file or tls_certcheck=off for TLS
    sessions, so that msmtp is not silently vulnerable to
    man-in-the-middle attacks.
  - Do not use NTLM authentication automatically anymore unless TLS
    is active.  NTLM is not an open standard and must therefore be
    considered broken.
  - Gnulib update 2007-04-07.
* Sun Jan 21 2007 mrueckert@suse.de
- update to 1.4.10:
  - Updated copyright info to 2007.
  - Gnulib update to 2007-01-10.
  - From mpop: Switch to autoconf-2.61 and automake-1.10, to avoid
    problems with configure trying to run "sh /usr/bin/install"
    where /usr/bin/install is not a shell script on NetBSD.
    Reported by Jeremy C. Reed.
  - From mpop: Remove the obsolete "extern int errno;" declaration.
    It does not conform to POSIX and causes trouble. Thanks to
    Jeremy C. Reed for the patch.
  - Added AC_SYS_LARGEFILE to configure.ac, for large file support.
    Removed the unnecessary AC_C_CONST and AC_HEADER_STDC.
* Mon Nov  6 2006 mrueckert@suse.de
- update to version 1.4.9:
  Some minor build problems were fixed, and the gnulib portability
  library was updated.
* Mon Aug 21 2006 mrueckert@suse.de
- Update to version 1.4.7:
  o added option to enforce SSLv3
  o many small bugfixes
* Sun Jun 18 2006 mrueckert@suse.de
- Update to version 1.4.6:
  o idn support
  o many small changes for details see
    /usr/share/doc/packages/msmtp/ChangeLog
  o small cleanup for the spec file
- added msmtpqueue-0.4 as part to the msmtp package
  (no need for an own script for 2 shell script)
  Adds basic queueing capabilities to msmtp
- build with -fstack-protector on > 10.0
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 19 2005 arvin@suse.de
- updated to version 1.4.4
* Mon Jul 18 2005 arvin@suse.de
- updated to version 1.4.3
* Mon Jul 11 2005 arvin@suse.de
- initial package with version 1.4.2
